# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ReplicationPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'description': 'str',
        'src_registry': 'Registry',
        'dest_registry': 'Registry',
        'dest_namespace': 'str',
        'dest_namespace_replace_count': 'int',
        'trigger': 'ReplicationTrigger',
        'filters': 'list[ReplicationFilter]',
        'replicate_deletion': 'bool',
        'deletion': 'bool',
        'override': 'bool',
        'enabled': 'bool',
        'creation_time': 'datetime',
        'update_time': 'datetime',
        'speed': 'int',
        'copy_by_chunk': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'src_registry': 'src_registry',
        'dest_registry': 'dest_registry',
        'dest_namespace': 'dest_namespace',
        'dest_namespace_replace_count': 'dest_namespace_replace_count',
        'trigger': 'trigger',
        'filters': 'filters',
        'replicate_deletion': 'replicate_deletion',
        'deletion': 'deletion',
        'override': 'override',
        'enabled': 'enabled',
        'creation_time': 'creation_time',
        'update_time': 'update_time',
        'speed': 'speed',
        'copy_by_chunk': 'copy_by_chunk'
    }

    def __init__(self, id=None, name=None, description=None, src_registry=None, dest_registry=None, dest_namespace=None, dest_namespace_replace_count=None, trigger=None, filters=None, replicate_deletion=None, deletion=None, override=None, enabled=None, creation_time=None, update_time=None, speed=None, copy_by_chunk=None, _configuration=None):  # noqa: E501
        """ReplicationPolicy - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._description = None
        self._src_registry = None
        self._dest_registry = None
        self._dest_namespace = None
        self._dest_namespace_replace_count = None
        self._trigger = None
        self._filters = None
        self._replicate_deletion = None
        self._deletion = None
        self._override = None
        self._enabled = None
        self._creation_time = None
        self._update_time = None
        self._speed = None
        self._copy_by_chunk = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if src_registry is not None:
            self.src_registry = src_registry
        if dest_registry is not None:
            self.dest_registry = dest_registry
        if dest_namespace is not None:
            self.dest_namespace = dest_namespace
        if dest_namespace_replace_count is not None:
            self.dest_namespace_replace_count = dest_namespace_replace_count
        if trigger is not None:
            self.trigger = trigger
        if filters is not None:
            self.filters = filters
        if replicate_deletion is not None:
            self.replicate_deletion = replicate_deletion
        if deletion is not None:
            self.deletion = deletion
        if override is not None:
            self.override = override
        if enabled is not None:
            self.enabled = enabled
        if creation_time is not None:
            self.creation_time = creation_time
        if update_time is not None:
            self.update_time = update_time
        if speed is not None:
            self.speed = speed
        if copy_by_chunk is not None:
            self.copy_by_chunk = copy_by_chunk

    @property
    def id(self):
        """Gets the id of this ReplicationPolicy.  # noqa: E501

        The policy ID.  # noqa: E501

        :return: The id of this ReplicationPolicy.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ReplicationPolicy.

        The policy ID.  # noqa: E501

        :param id: The id of this ReplicationPolicy.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ReplicationPolicy.  # noqa: E501

        The policy name.  # noqa: E501

        :return: The name of this ReplicationPolicy.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ReplicationPolicy.

        The policy name.  # noqa: E501

        :param name: The name of this ReplicationPolicy.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this ReplicationPolicy.  # noqa: E501

        The description of the policy.  # noqa: E501

        :return: The description of this ReplicationPolicy.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ReplicationPolicy.

        The description of the policy.  # noqa: E501

        :param description: The description of this ReplicationPolicy.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def src_registry(self):
        """Gets the src_registry of this ReplicationPolicy.  # noqa: E501

        The source registry.  # noqa: E501

        :return: The src_registry of this ReplicationPolicy.  # noqa: E501
        :rtype: Registry
        """
        return self._src_registry

    @src_registry.setter
    def src_registry(self, src_registry):
        """Sets the src_registry of this ReplicationPolicy.

        The source registry.  # noqa: E501

        :param src_registry: The src_registry of this ReplicationPolicy.  # noqa: E501
        :type: Registry
        """

        self._src_registry = src_registry

    @property
    def dest_registry(self):
        """Gets the dest_registry of this ReplicationPolicy.  # noqa: E501

        The destination registry.  # noqa: E501

        :return: The dest_registry of this ReplicationPolicy.  # noqa: E501
        :rtype: Registry
        """
        return self._dest_registry

    @dest_registry.setter
    def dest_registry(self, dest_registry):
        """Sets the dest_registry of this ReplicationPolicy.

        The destination registry.  # noqa: E501

        :param dest_registry: The dest_registry of this ReplicationPolicy.  # noqa: E501
        :type: Registry
        """

        self._dest_registry = dest_registry

    @property
    def dest_namespace(self):
        """Gets the dest_namespace of this ReplicationPolicy.  # noqa: E501

        The destination namespace.  # noqa: E501

        :return: The dest_namespace of this ReplicationPolicy.  # noqa: E501
        :rtype: str
        """
        return self._dest_namespace

    @dest_namespace.setter
    def dest_namespace(self, dest_namespace):
        """Sets the dest_namespace of this ReplicationPolicy.

        The destination namespace.  # noqa: E501

        :param dest_namespace: The dest_namespace of this ReplicationPolicy.  # noqa: E501
        :type: str
        """

        self._dest_namespace = dest_namespace

    @property
    def dest_namespace_replace_count(self):
        """Gets the dest_namespace_replace_count of this ReplicationPolicy.  # noqa: E501

        Specify how many path components will be replaced by the provided destination namespace. The default value is -1 in which case the legacy mode will be applied.  # noqa: E501

        :return: The dest_namespace_replace_count of this ReplicationPolicy.  # noqa: E501
        :rtype: int
        """
        return self._dest_namespace_replace_count

    @dest_namespace_replace_count.setter
    def dest_namespace_replace_count(self, dest_namespace_replace_count):
        """Sets the dest_namespace_replace_count of this ReplicationPolicy.

        Specify how many path components will be replaced by the provided destination namespace. The default value is -1 in which case the legacy mode will be applied.  # noqa: E501

        :param dest_namespace_replace_count: The dest_namespace_replace_count of this ReplicationPolicy.  # noqa: E501
        :type: int
        """

        self._dest_namespace_replace_count = dest_namespace_replace_count

    @property
    def trigger(self):
        """Gets the trigger of this ReplicationPolicy.  # noqa: E501


        :return: The trigger of this ReplicationPolicy.  # noqa: E501
        :rtype: ReplicationTrigger
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this ReplicationPolicy.


        :param trigger: The trigger of this ReplicationPolicy.  # noqa: E501
        :type: ReplicationTrigger
        """

        self._trigger = trigger

    @property
    def filters(self):
        """Gets the filters of this ReplicationPolicy.  # noqa: E501

        The replication policy filter array.  # noqa: E501

        :return: The filters of this ReplicationPolicy.  # noqa: E501
        :rtype: list[ReplicationFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this ReplicationPolicy.

        The replication policy filter array.  # noqa: E501

        :param filters: The filters of this ReplicationPolicy.  # noqa: E501
        :type: list[ReplicationFilter]
        """

        self._filters = filters

    @property
    def replicate_deletion(self):
        """Gets the replicate_deletion of this ReplicationPolicy.  # noqa: E501

        Whether to replicate the deletion operation.  # noqa: E501

        :return: The replicate_deletion of this ReplicationPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._replicate_deletion

    @replicate_deletion.setter
    def replicate_deletion(self, replicate_deletion):
        """Sets the replicate_deletion of this ReplicationPolicy.

        Whether to replicate the deletion operation.  # noqa: E501

        :param replicate_deletion: The replicate_deletion of this ReplicationPolicy.  # noqa: E501
        :type: bool
        """

        self._replicate_deletion = replicate_deletion

    @property
    def deletion(self):
        """Gets the deletion of this ReplicationPolicy.  # noqa: E501

        Deprecated, use \"replicate_deletion\" instead. Whether to replicate the deletion operation.  # noqa: E501

        :return: The deletion of this ReplicationPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._deletion

    @deletion.setter
    def deletion(self, deletion):
        """Sets the deletion of this ReplicationPolicy.

        Deprecated, use \"replicate_deletion\" instead. Whether to replicate the deletion operation.  # noqa: E501

        :param deletion: The deletion of this ReplicationPolicy.  # noqa: E501
        :type: bool
        """

        self._deletion = deletion

    @property
    def override(self):
        """Gets the override of this ReplicationPolicy.  # noqa: E501

        Whether to override the resources on the destination registry.  # noqa: E501

        :return: The override of this ReplicationPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._override

    @override.setter
    def override(self, override):
        """Sets the override of this ReplicationPolicy.

        Whether to override the resources on the destination registry.  # noqa: E501

        :param override: The override of this ReplicationPolicy.  # noqa: E501
        :type: bool
        """

        self._override = override

    @property
    def enabled(self):
        """Gets the enabled of this ReplicationPolicy.  # noqa: E501

        Whether the policy is enabled or not.  # noqa: E501

        :return: The enabled of this ReplicationPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ReplicationPolicy.

        Whether the policy is enabled or not.  # noqa: E501

        :param enabled: The enabled of this ReplicationPolicy.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def creation_time(self):
        """Gets the creation_time of this ReplicationPolicy.  # noqa: E501

        The create time of the policy.  # noqa: E501

        :return: The creation_time of this ReplicationPolicy.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this ReplicationPolicy.

        The create time of the policy.  # noqa: E501

        :param creation_time: The creation_time of this ReplicationPolicy.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def update_time(self):
        """Gets the update_time of this ReplicationPolicy.  # noqa: E501

        The update time of the policy.  # noqa: E501

        :return: The update_time of this ReplicationPolicy.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this ReplicationPolicy.

        The update time of the policy.  # noqa: E501

        :param update_time: The update_time of this ReplicationPolicy.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    @property
    def speed(self):
        """Gets the speed of this ReplicationPolicy.  # noqa: E501

        speed limit for each task  # noqa: E501

        :return: The speed of this ReplicationPolicy.  # noqa: E501
        :rtype: int
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this ReplicationPolicy.

        speed limit for each task  # noqa: E501

        :param speed: The speed of this ReplicationPolicy.  # noqa: E501
        :type: int
        """

        self._speed = speed

    @property
    def copy_by_chunk(self):
        """Gets the copy_by_chunk of this ReplicationPolicy.  # noqa: E501

        Whether to enable copy by chunk.  # noqa: E501

        :return: The copy_by_chunk of this ReplicationPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._copy_by_chunk

    @copy_by_chunk.setter
    def copy_by_chunk(self, copy_by_chunk):
        """Sets the copy_by_chunk of this ReplicationPolicy.

        Whether to enable copy by chunk.  # noqa: E501

        :param copy_by_chunk: The copy_by_chunk of this ReplicationPolicy.  # noqa: E501
        :type: bool
        """

        self._copy_by_chunk = copy_by_chunk

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReplicationPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReplicationPolicy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReplicationPolicy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Instance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'description': 'str',
        'vendor': 'str',
        'endpoint': 'str',
        'auth_mode': 'str',
        'auth_info': 'dict(str, str)',
        'status': 'str',
        'enabled': 'bool',
        'default': 'bool',
        'insecure': 'bool',
        'setup_timestamp': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'vendor': 'vendor',
        'endpoint': 'endpoint',
        'auth_mode': 'auth_mode',
        'auth_info': 'auth_info',
        'status': 'status',
        'enabled': 'enabled',
        'default': 'default',
        'insecure': 'insecure',
        'setup_timestamp': 'setup_timestamp'
    }

    def __init__(self, id=None, name=None, description=None, vendor=None, endpoint=None, auth_mode=None, auth_info=None, status=None, enabled=None, default=None, insecure=None, setup_timestamp=None, _configuration=None):  # noqa: E501
        """Instance - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._description = None
        self._vendor = None
        self._endpoint = None
        self._auth_mode = None
        self._auth_info = None
        self._status = None
        self._enabled = None
        self._default = None
        self._insecure = None
        self._setup_timestamp = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if vendor is not None:
            self.vendor = vendor
        if endpoint is not None:
            self.endpoint = endpoint
        if auth_mode is not None:
            self.auth_mode = auth_mode
        if auth_info is not None:
            self.auth_info = auth_info
        if status is not None:
            self.status = status
        if enabled is not None:
            self.enabled = enabled
        if default is not None:
            self.default = default
        if insecure is not None:
            self.insecure = insecure
        if setup_timestamp is not None:
            self.setup_timestamp = setup_timestamp

    @property
    def id(self):
        """Gets the id of this Instance.  # noqa: E501

        Unique ID  # noqa: E501

        :return: The id of this Instance.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Instance.

        Unique ID  # noqa: E501

        :param id: The id of this Instance.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Instance.  # noqa: E501

        Instance name  # noqa: E501

        :return: The name of this Instance.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Instance.

        Instance name  # noqa: E501

        :param name: The name of this Instance.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this Instance.  # noqa: E501

        Description of instance  # noqa: E501

        :return: The description of this Instance.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Instance.

        Description of instance  # noqa: E501

        :param description: The description of this Instance.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def vendor(self):
        """Gets the vendor of this Instance.  # noqa: E501

        Based on which driver, identified by ID  # noqa: E501

        :return: The vendor of this Instance.  # noqa: E501
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """Sets the vendor of this Instance.

        Based on which driver, identified by ID  # noqa: E501

        :param vendor: The vendor of this Instance.  # noqa: E501
        :type: str
        """

        self._vendor = vendor

    @property
    def endpoint(self):
        """Gets the endpoint of this Instance.  # noqa: E501

        The service endpoint of this instance  # noqa: E501

        :return: The endpoint of this Instance.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this Instance.

        The service endpoint of this instance  # noqa: E501

        :param endpoint: The endpoint of this Instance.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def auth_mode(self):
        """Gets the auth_mode of this Instance.  # noqa: E501

        The authentication way supported  # noqa: E501

        :return: The auth_mode of this Instance.  # noqa: E501
        :rtype: str
        """
        return self._auth_mode

    @auth_mode.setter
    def auth_mode(self, auth_mode):
        """Sets the auth_mode of this Instance.

        The authentication way supported  # noqa: E501

        :param auth_mode: The auth_mode of this Instance.  # noqa: E501
        :type: str
        """

        self._auth_mode = auth_mode

    @property
    def auth_info(self):
        """Gets the auth_info of this Instance.  # noqa: E501

        The auth credential data if exists  # noqa: E501

        :return: The auth_info of this Instance.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._auth_info

    @auth_info.setter
    def auth_info(self, auth_info):
        """Sets the auth_info of this Instance.

        The auth credential data if exists  # noqa: E501

        :param auth_info: The auth_info of this Instance.  # noqa: E501
        :type: dict(str, str)
        """

        self._auth_info = auth_info

    @property
    def status(self):
        """Gets the status of this Instance.  # noqa: E501

        The health status  # noqa: E501

        :return: The status of this Instance.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Instance.

        The health status  # noqa: E501

        :param status: The status of this Instance.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def enabled(self):
        """Gets the enabled of this Instance.  # noqa: E501

        Whether the instance is activated or not  # noqa: E501

        :return: The enabled of this Instance.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this Instance.

        Whether the instance is activated or not  # noqa: E501

        :param enabled: The enabled of this Instance.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def default(self):
        """Gets the default of this Instance.  # noqa: E501

        Whether the instance is default or not  # noqa: E501

        :return: The default of this Instance.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this Instance.

        Whether the instance is default or not  # noqa: E501

        :param default: The default of this Instance.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def insecure(self):
        """Gets the insecure of this Instance.  # noqa: E501

        Whether the instance endpoint is insecure or not  # noqa: E501

        :return: The insecure of this Instance.  # noqa: E501
        :rtype: bool
        """
        return self._insecure

    @insecure.setter
    def insecure(self, insecure):
        """Sets the insecure of this Instance.

        Whether the instance endpoint is insecure or not  # noqa: E501

        :param insecure: The insecure of this Instance.  # noqa: E501
        :type: bool
        """

        self._insecure = insecure

    @property
    def setup_timestamp(self):
        """Gets the setup_timestamp of this Instance.  # noqa: E501

        The timestamp of instance setting up  # noqa: E501

        :return: The setup_timestamp of this Instance.  # noqa: E501
        :rtype: int
        """
        return self._setup_timestamp

    @setup_timestamp.setter
    def setup_timestamp(self, setup_timestamp):
        """Sets the setup_timestamp of this Instance.

        The timestamp of instance setting up  # noqa: E501

        :param setup_timestamp: The setup_timestamp of this Instance.  # noqa: E501
        :type: int
        """

        self._setup_timestamp = setup_timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Instance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Instance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Instance):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ProjectMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'public': 'str',
        'enable_content_trust': 'str',
        'enable_content_trust_cosign': 'str',
        'prevent_vul': 'str',
        'severity': 'str',
        'auto_scan': 'str',
        'reuse_sys_cve_allowlist': 'str',
        'retention_id': 'str'
    }

    attribute_map = {
        'public': 'public',
        'enable_content_trust': 'enable_content_trust',
        'enable_content_trust_cosign': 'enable_content_trust_cosign',
        'prevent_vul': 'prevent_vul',
        'severity': 'severity',
        'auto_scan': 'auto_scan',
        'reuse_sys_cve_allowlist': 'reuse_sys_cve_allowlist',
        'retention_id': 'retention_id'
    }

    def __init__(self, public=None, enable_content_trust=None, enable_content_trust_cosign=None, prevent_vul=None, severity=None, auto_scan=None, reuse_sys_cve_allowlist=None, retention_id=None, _configuration=None):  # noqa: E501
        """ProjectMetadata - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._public = None
        self._enable_content_trust = None
        self._enable_content_trust_cosign = None
        self._prevent_vul = None
        self._severity = None
        self._auto_scan = None
        self._reuse_sys_cve_allowlist = None
        self._retention_id = None
        self.discriminator = None

        if public is not None:
            self.public = public
        if enable_content_trust is not None:
            self.enable_content_trust = enable_content_trust
        if enable_content_trust_cosign is not None:
            self.enable_content_trust_cosign = enable_content_trust_cosign
        if prevent_vul is not None:
            self.prevent_vul = prevent_vul
        if severity is not None:
            self.severity = severity
        if auto_scan is not None:
            self.auto_scan = auto_scan
        if reuse_sys_cve_allowlist is not None:
            self.reuse_sys_cve_allowlist = reuse_sys_cve_allowlist
        if retention_id is not None:
            self.retention_id = retention_id

    @property
    def public(self):
        """Gets the public of this ProjectMetadata.  # noqa: E501

        The public status of the project. The valid values are \"true\", \"false\".  # noqa: E501

        :return: The public of this ProjectMetadata.  # noqa: E501
        :rtype: str
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this ProjectMetadata.

        The public status of the project. The valid values are \"true\", \"false\".  # noqa: E501

        :param public: The public of this ProjectMetadata.  # noqa: E501
        :type: str
        """

        self._public = public

    @property
    def enable_content_trust(self):
        """Gets the enable_content_trust of this ProjectMetadata.  # noqa: E501

        Whether content trust is enabled or not. If it is enabled, user can't pull unsigned images from this project. The valid values are \"true\", \"false\".  # noqa: E501

        :return: The enable_content_trust of this ProjectMetadata.  # noqa: E501
        :rtype: str
        """
        return self._enable_content_trust

    @enable_content_trust.setter
    def enable_content_trust(self, enable_content_trust):
        """Sets the enable_content_trust of this ProjectMetadata.

        Whether content trust is enabled or not. If it is enabled, user can't pull unsigned images from this project. The valid values are \"true\", \"false\".  # noqa: E501

        :param enable_content_trust: The enable_content_trust of this ProjectMetadata.  # noqa: E501
        :type: str
        """

        self._enable_content_trust = enable_content_trust

    @property
    def enable_content_trust_cosign(self):
        """Gets the enable_content_trust_cosign of this ProjectMetadata.  # noqa: E501

        Whether cosign content trust is enabled or not. If it is enabled, user can't pull images without cosign signature from this project. The valid values are \"true\", \"false\".  # noqa: E501

        :return: The enable_content_trust_cosign of this ProjectMetadata.  # noqa: E501
        :rtype: str
        """
        return self._enable_content_trust_cosign

    @enable_content_trust_cosign.setter
    def enable_content_trust_cosign(self, enable_content_trust_cosign):
        """Sets the enable_content_trust_cosign of this ProjectMetadata.

        Whether cosign content trust is enabled or not. If it is enabled, user can't pull images without cosign signature from this project. The valid values are \"true\", \"false\".  # noqa: E501

        :param enable_content_trust_cosign: The enable_content_trust_cosign of this ProjectMetadata.  # noqa: E501
        :type: str
        """

        self._enable_content_trust_cosign = enable_content_trust_cosign

    @property
    def prevent_vul(self):
        """Gets the prevent_vul of this ProjectMetadata.  # noqa: E501

        Whether prevent the vulnerable images from running. The valid values are \"true\", \"false\".  # noqa: E501

        :return: The prevent_vul of this ProjectMetadata.  # noqa: E501
        :rtype: str
        """
        return self._prevent_vul

    @prevent_vul.setter
    def prevent_vul(self, prevent_vul):
        """Sets the prevent_vul of this ProjectMetadata.

        Whether prevent the vulnerable images from running. The valid values are \"true\", \"false\".  # noqa: E501

        :param prevent_vul: The prevent_vul of this ProjectMetadata.  # noqa: E501
        :type: str
        """

        self._prevent_vul = prevent_vul

    @property
    def severity(self):
        """Gets the severity of this ProjectMetadata.  # noqa: E501

        If the vulnerability is high than severity defined here, the images can't be pulled. The valid values are \"none\", \"low\", \"medium\", \"high\", \"critical\".  # noqa: E501

        :return: The severity of this ProjectMetadata.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this ProjectMetadata.

        If the vulnerability is high than severity defined here, the images can't be pulled. The valid values are \"none\", \"low\", \"medium\", \"high\", \"critical\".  # noqa: E501

        :param severity: The severity of this ProjectMetadata.  # noqa: E501
        :type: str
        """

        self._severity = severity

    @property
    def auto_scan(self):
        """Gets the auto_scan of this ProjectMetadata.  # noqa: E501

        Whether scan images automatically when pushing. The valid values are \"true\", \"false\".  # noqa: E501

        :return: The auto_scan of this ProjectMetadata.  # noqa: E501
        :rtype: str
        """
        return self._auto_scan

    @auto_scan.setter
    def auto_scan(self, auto_scan):
        """Sets the auto_scan of this ProjectMetadata.

        Whether scan images automatically when pushing. The valid values are \"true\", \"false\".  # noqa: E501

        :param auto_scan: The auto_scan of this ProjectMetadata.  # noqa: E501
        :type: str
        """

        self._auto_scan = auto_scan

    @property
    def reuse_sys_cve_allowlist(self):
        """Gets the reuse_sys_cve_allowlist of this ProjectMetadata.  # noqa: E501

        Whether this project reuse the system level CVE allowlist as the allowlist of its own.  The valid values are \"true\", \"false\". If it is set to \"true\" the actual allowlist associate with this project, if any, will be ignored.  # noqa: E501

        :return: The reuse_sys_cve_allowlist of this ProjectMetadata.  # noqa: E501
        :rtype: str
        """
        return self._reuse_sys_cve_allowlist

    @reuse_sys_cve_allowlist.setter
    def reuse_sys_cve_allowlist(self, reuse_sys_cve_allowlist):
        """Sets the reuse_sys_cve_allowlist of this ProjectMetadata.

        Whether this project reuse the system level CVE allowlist as the allowlist of its own.  The valid values are \"true\", \"false\". If it is set to \"true\" the actual allowlist associate with this project, if any, will be ignored.  # noqa: E501

        :param reuse_sys_cve_allowlist: The reuse_sys_cve_allowlist of this ProjectMetadata.  # noqa: E501
        :type: str
        """

        self._reuse_sys_cve_allowlist = reuse_sys_cve_allowlist

    @property
    def retention_id(self):
        """Gets the retention_id of this ProjectMetadata.  # noqa: E501

        The ID of the tag retention policy for the project  # noqa: E501

        :return: The retention_id of this ProjectMetadata.  # noqa: E501
        :rtype: str
        """
        return self._retention_id

    @retention_id.setter
    def retention_id(self, retention_id):
        """Sets the retention_id of this ProjectMetadata.

        The ID of the tag retention policy for the project  # noqa: E501

        :param retention_id: The retention_id of this ProjectMetadata.  # noqa: E501
        :type: str
        """

        self._retention_id = retention_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProjectMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Task(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'execution_id': 'int',
        'status': 'str',
        'status_message': 'str',
        'run_count': 'int',
        'extra_attrs': 'ExtraAttrs',
        'creation_time': 'str',
        'update_time': 'str',
        'start_time': 'str',
        'end_time': 'str'
    }

    attribute_map = {
        'id': 'id',
        'execution_id': 'execution_id',
        'status': 'status',
        'status_message': 'status_message',
        'run_count': 'run_count',
        'extra_attrs': 'extra_attrs',
        'creation_time': 'creation_time',
        'update_time': 'update_time',
        'start_time': 'start_time',
        'end_time': 'end_time'
    }

    def __init__(self, id=None, execution_id=None, status=None, status_message=None, run_count=None, extra_attrs=None, creation_time=None, update_time=None, start_time=None, end_time=None, _configuration=None):  # noqa: E501
        """Task - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._execution_id = None
        self._status = None
        self._status_message = None
        self._run_count = None
        self._extra_attrs = None
        self._creation_time = None
        self._update_time = None
        self._start_time = None
        self._end_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if execution_id is not None:
            self.execution_id = execution_id
        if status is not None:
            self.status = status
        if status_message is not None:
            self.status_message = status_message
        if run_count is not None:
            self.run_count = run_count
        if extra_attrs is not None:
            self.extra_attrs = extra_attrs
        if creation_time is not None:
            self.creation_time = creation_time
        if update_time is not None:
            self.update_time = update_time
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time

    @property
    def id(self):
        """Gets the id of this Task.  # noqa: E501

        The ID of task  # noqa: E501

        :return: The id of this Task.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Task.

        The ID of task  # noqa: E501

        :param id: The id of this Task.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def execution_id(self):
        """Gets the execution_id of this Task.  # noqa: E501

        The ID of task execution  # noqa: E501

        :return: The execution_id of this Task.  # noqa: E501
        :rtype: int
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this Task.

        The ID of task execution  # noqa: E501

        :param execution_id: The execution_id of this Task.  # noqa: E501
        :type: int
        """

        self._execution_id = execution_id

    @property
    def status(self):
        """Gets the status of this Task.  # noqa: E501

        The status of task  # noqa: E501

        :return: The status of this Task.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Task.

        The status of task  # noqa: E501

        :param status: The status of this Task.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def status_message(self):
        """Gets the status_message of this Task.  # noqa: E501

        The status message of task  # noqa: E501

        :return: The status_message of this Task.  # noqa: E501
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """Sets the status_message of this Task.

        The status message of task  # noqa: E501

        :param status_message: The status_message of this Task.  # noqa: E501
        :type: str
        """

        self._status_message = status_message

    @property
    def run_count(self):
        """Gets the run_count of this Task.  # noqa: E501

        The count of task run  # noqa: E501

        :return: The run_count of this Task.  # noqa: E501
        :rtype: int
        """
        return self._run_count

    @run_count.setter
    def run_count(self, run_count):
        """Sets the run_count of this Task.

        The count of task run  # noqa: E501

        :param run_count: The run_count of this Task.  # noqa: E501
        :type: int
        """

        self._run_count = run_count

    @property
    def extra_attrs(self):
        """Gets the extra_attrs of this Task.  # noqa: E501


        :return: The extra_attrs of this Task.  # noqa: E501
        :rtype: ExtraAttrs
        """
        return self._extra_attrs

    @extra_attrs.setter
    def extra_attrs(self, extra_attrs):
        """Sets the extra_attrs of this Task.


        :param extra_attrs: The extra_attrs of this Task.  # noqa: E501
        :type: ExtraAttrs
        """

        self._extra_attrs = extra_attrs

    @property
    def creation_time(self):
        """Gets the creation_time of this Task.  # noqa: E501

        The creation time of task  # noqa: E501

        :return: The creation_time of this Task.  # noqa: E501
        :rtype: str
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this Task.

        The creation time of task  # noqa: E501

        :param creation_time: The creation_time of this Task.  # noqa: E501
        :type: str
        """

        self._creation_time = creation_time

    @property
    def update_time(self):
        """Gets the update_time of this Task.  # noqa: E501

        The update time of task  # noqa: E501

        :return: The update_time of this Task.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Task.

        The update time of task  # noqa: E501

        :param update_time: The update_time of this Task.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def start_time(self):
        """Gets the start_time of this Task.  # noqa: E501

        The start time of task  # noqa: E501

        :return: The start_time of this Task.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this Task.

        The start time of task  # noqa: E501

        :param start_time: The start_time of this Task.  # noqa: E501
        :type: str
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this Task.  # noqa: E501

        The end time of task  # noqa: E501

        :return: The end_time of this Task.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this Task.

        The end time of task  # noqa: E501

        :param end_time: The end_time of this Task.  # noqa: E501
        :type: str
        """

        self._end_time = end_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Task, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Task):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Task):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class WebhookTargetObject(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'address': 'str',
        'auth_header': 'str',
        'skip_cert_verify': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'address': 'address',
        'auth_header': 'auth_header',
        'skip_cert_verify': 'skip_cert_verify'
    }

    def __init__(self, type=None, address=None, auth_header=None, skip_cert_verify=None, _configuration=None):  # noqa: E501
        """WebhookTargetObject - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._type = None
        self._address = None
        self._auth_header = None
        self._skip_cert_verify = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if address is not None:
            self.address = address
        if auth_header is not None:
            self.auth_header = auth_header
        if skip_cert_verify is not None:
            self.skip_cert_verify = skip_cert_verify

    @property
    def type(self):
        """Gets the type of this WebhookTargetObject.  # noqa: E501

        The webhook target notify type.  # noqa: E501

        :return: The type of this WebhookTargetObject.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this WebhookTargetObject.

        The webhook target notify type.  # noqa: E501

        :param type: The type of this WebhookTargetObject.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def address(self):
        """Gets the address of this WebhookTargetObject.  # noqa: E501

        The webhook target address.  # noqa: E501

        :return: The address of this WebhookTargetObject.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this WebhookTargetObject.

        The webhook target address.  # noqa: E501

        :param address: The address of this WebhookTargetObject.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def auth_header(self):
        """Gets the auth_header of this WebhookTargetObject.  # noqa: E501

        The webhook auth header.  # noqa: E501

        :return: The auth_header of this WebhookTargetObject.  # noqa: E501
        :rtype: str
        """
        return self._auth_header

    @auth_header.setter
    def auth_header(self, auth_header):
        """Sets the auth_header of this WebhookTargetObject.

        The webhook auth header.  # noqa: E501

        :param auth_header: The auth_header of this WebhookTargetObject.  # noqa: E501
        :type: str
        """

        self._auth_header = auth_header

    @property
    def skip_cert_verify(self):
        """Gets the skip_cert_verify of this WebhookTargetObject.  # noqa: E501

        Whether or not to skip cert verify.  # noqa: E501

        :return: The skip_cert_verify of this WebhookTargetObject.  # noqa: E501
        :rtype: bool
        """
        return self._skip_cert_verify

    @skip_cert_verify.setter
    def skip_cert_verify(self, skip_cert_verify):
        """Sets the skip_cert_verify of this WebhookTargetObject.

        Whether or not to skip cert verify.  # noqa: E501

        :param skip_cert_verify: The skip_cert_verify of this WebhookTargetObject.  # noqa: E501
        :type: bool
        """

        self._skip_cert_verify = skip_cert_verify

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookTargetObject, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookTargetObject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookTargetObject):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class SearchRepository(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project_id': 'int',
        'project_name': 'str',
        'project_public': 'bool',
        'repository_name': 'str',
        'pull_count': 'int',
        'artifact_count': 'int'
    }

    attribute_map = {
        'project_id': 'project_id',
        'project_name': 'project_name',
        'project_public': 'project_public',
        'repository_name': 'repository_name',
        'pull_count': 'pull_count',
        'artifact_count': 'artifact_count'
    }

    def __init__(self, project_id=None, project_name=None, project_public=None, repository_name=None, pull_count=None, artifact_count=None, _configuration=None):  # noqa: E501
        """SearchRepository - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._project_id = None
        self._project_name = None
        self._project_public = None
        self._repository_name = None
        self._pull_count = None
        self._artifact_count = None
        self.discriminator = None

        if project_id is not None:
            self.project_id = project_id
        if project_name is not None:
            self.project_name = project_name
        if project_public is not None:
            self.project_public = project_public
        if repository_name is not None:
            self.repository_name = repository_name
        if pull_count is not None:
            self.pull_count = pull_count
        if artifact_count is not None:
            self.artifact_count = artifact_count

    @property
    def project_id(self):
        """Gets the project_id of this SearchRepository.  # noqa: E501

        The ID of the project that the repository belongs to  # noqa: E501

        :return: The project_id of this SearchRepository.  # noqa: E501
        :rtype: int
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this SearchRepository.

        The ID of the project that the repository belongs to  # noqa: E501

        :param project_id: The project_id of this SearchRepository.  # noqa: E501
        :type: int
        """

        self._project_id = project_id

    @property
    def project_name(self):
        """Gets the project_name of this SearchRepository.  # noqa: E501

        The name of the project that the repository belongs to  # noqa: E501

        :return: The project_name of this SearchRepository.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this SearchRepository.

        The name of the project that the repository belongs to  # noqa: E501

        :param project_name: The project_name of this SearchRepository.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def project_public(self):
        """Gets the project_public of this SearchRepository.  # noqa: E501

        The flag to indicate the publicity of the project that the repository belongs to (1 is public, 0 is not)  # noqa: E501

        :return: The project_public of this SearchRepository.  # noqa: E501
        :rtype: bool
        """
        return self._project_public

    @project_public.setter
    def project_public(self, project_public):
        """Sets the project_public of this SearchRepository.

        The flag to indicate the publicity of the project that the repository belongs to (1 is public, 0 is not)  # noqa: E501

        :param project_public: The project_public of this SearchRepository.  # noqa: E501
        :type: bool
        """

        self._project_public = project_public

    @property
    def repository_name(self):
        """Gets the repository_name of this SearchRepository.  # noqa: E501

        The name of the repository  # noqa: E501

        :return: The repository_name of this SearchRepository.  # noqa: E501
        :rtype: str
        """
        return self._repository_name

    @repository_name.setter
    def repository_name(self, repository_name):
        """Sets the repository_name of this SearchRepository.

        The name of the repository  # noqa: E501

        :param repository_name: The repository_name of this SearchRepository.  # noqa: E501
        :type: str
        """

        self._repository_name = repository_name

    @property
    def pull_count(self):
        """Gets the pull_count of this SearchRepository.  # noqa: E501

        The count how many times the repository is pulled  # noqa: E501

        :return: The pull_count of this SearchRepository.  # noqa: E501
        :rtype: int
        """
        return self._pull_count

    @pull_count.setter
    def pull_count(self, pull_count):
        """Sets the pull_count of this SearchRepository.

        The count how many times the repository is pulled  # noqa: E501

        :param pull_count: The pull_count of this SearchRepository.  # noqa: E501
        :type: int
        """

        self._pull_count = pull_count

    @property
    def artifact_count(self):
        """Gets the artifact_count of this SearchRepository.  # noqa: E501

        The count of artifacts in the repository  # noqa: E501

        :return: The artifact_count of this SearchRepository.  # noqa: E501
        :rtype: int
        """
        return self._artifact_count

    @artifact_count.setter
    def artifact_count(self, artifact_count):
        """Sets the artifact_count of this SearchRepository.

        The count of artifacts in the repository  # noqa: E501

        :param artifact_count: The artifact_count of this SearchRepository.  # noqa: E501
        :type: int
        """

        self._artifact_count = artifact_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SearchRepository, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchRepository):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchRepository):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class RetentionExecution(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'policy_id': 'int',
        'start_time': 'str',
        'end_time': 'str',
        'status': 'str',
        'trigger': 'str',
        'dry_run': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'policy_id': 'policy_id',
        'start_time': 'start_time',
        'end_time': 'end_time',
        'status': 'status',
        'trigger': 'trigger',
        'dry_run': 'dry_run'
    }

    def __init__(self, id=None, policy_id=None, start_time=None, end_time=None, status=None, trigger=None, dry_run=None, _configuration=None):  # noqa: E501
        """RetentionExecution - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._policy_id = None
        self._start_time = None
        self._end_time = None
        self._status = None
        self._trigger = None
        self._dry_run = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if policy_id is not None:
            self.policy_id = policy_id
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if status is not None:
            self.status = status
        if trigger is not None:
            self.trigger = trigger
        if dry_run is not None:
            self.dry_run = dry_run

    @property
    def id(self):
        """Gets the id of this RetentionExecution.  # noqa: E501


        :return: The id of this RetentionExecution.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RetentionExecution.


        :param id: The id of this RetentionExecution.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def policy_id(self):
        """Gets the policy_id of this RetentionExecution.  # noqa: E501


        :return: The policy_id of this RetentionExecution.  # noqa: E501
        :rtype: int
        """
        return self._policy_id

    @policy_id.setter
    def policy_id(self, policy_id):
        """Sets the policy_id of this RetentionExecution.


        :param policy_id: The policy_id of this RetentionExecution.  # noqa: E501
        :type: int
        """

        self._policy_id = policy_id

    @property
    def start_time(self):
        """Gets the start_time of this RetentionExecution.  # noqa: E501


        :return: The start_time of this RetentionExecution.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this RetentionExecution.


        :param start_time: The start_time of this RetentionExecution.  # noqa: E501
        :type: str
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this RetentionExecution.  # noqa: E501


        :return: The end_time of this RetentionExecution.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this RetentionExecution.


        :param end_time: The end_time of this RetentionExecution.  # noqa: E501
        :type: str
        """

        self._end_time = end_time

    @property
    def status(self):
        """Gets the status of this RetentionExecution.  # noqa: E501


        :return: The status of this RetentionExecution.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RetentionExecution.


        :param status: The status of this RetentionExecution.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def trigger(self):
        """Gets the trigger of this RetentionExecution.  # noqa: E501


        :return: The trigger of this RetentionExecution.  # noqa: E501
        :rtype: str
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this RetentionExecution.


        :param trigger: The trigger of this RetentionExecution.  # noqa: E501
        :type: str
        """

        self._trigger = trigger

    @property
    def dry_run(self):
        """Gets the dry_run of this RetentionExecution.  # noqa: E501


        :return: The dry_run of this RetentionExecution.  # noqa: E501
        :rtype: bool
        """
        return self._dry_run

    @dry_run.setter
    def dry_run(self, dry_run):
        """Sets the dry_run of this RetentionExecution.


        :param dry_run: The dry_run of this RetentionExecution.  # noqa: E501
        :type: bool
        """

        self._dry_run = dry_run

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RetentionExecution, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetentionExecution):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RetentionExecution):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class WebhookJob(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'policy_id': 'int',
        'event_type': 'str',
        'notify_type': 'str',
        'status': 'str',
        'job_detail': 'str',
        'creation_time': 'datetime',
        'update_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'policy_id': 'policy_id',
        'event_type': 'event_type',
        'notify_type': 'notify_type',
        'status': 'status',
        'job_detail': 'job_detail',
        'creation_time': 'creation_time',
        'update_time': 'update_time'
    }

    def __init__(self, id=None, policy_id=None, event_type=None, notify_type=None, status=None, job_detail=None, creation_time=None, update_time=None, _configuration=None):  # noqa: E501
        """WebhookJob - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._policy_id = None
        self._event_type = None
        self._notify_type = None
        self._status = None
        self._job_detail = None
        self._creation_time = None
        self._update_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if policy_id is not None:
            self.policy_id = policy_id
        if event_type is not None:
            self.event_type = event_type
        if notify_type is not None:
            self.notify_type = notify_type
        if status is not None:
            self.status = status
        if job_detail is not None:
            self.job_detail = job_detail
        if creation_time is not None:
            self.creation_time = creation_time
        if update_time is not None:
            self.update_time = update_time

    @property
    def id(self):
        """Gets the id of this WebhookJob.  # noqa: E501

        The webhook job ID.  # noqa: E501

        :return: The id of this WebhookJob.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookJob.

        The webhook job ID.  # noqa: E501

        :param id: The id of this WebhookJob.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def policy_id(self):
        """Gets the policy_id of this WebhookJob.  # noqa: E501

        The webhook policy ID.  # noqa: E501

        :return: The policy_id of this WebhookJob.  # noqa: E501
        :rtype: int
        """
        return self._policy_id

    @policy_id.setter
    def policy_id(self, policy_id):
        """Sets the policy_id of this WebhookJob.

        The webhook policy ID.  # noqa: E501

        :param policy_id: The policy_id of this WebhookJob.  # noqa: E501
        :type: int
        """

        self._policy_id = policy_id

    @property
    def event_type(self):
        """Gets the event_type of this WebhookJob.  # noqa: E501

        The webhook job event type.  # noqa: E501

        :return: The event_type of this WebhookJob.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this WebhookJob.

        The webhook job event type.  # noqa: E501

        :param event_type: The event_type of this WebhookJob.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def notify_type(self):
        """Gets the notify_type of this WebhookJob.  # noqa: E501

        The webhook job notify type.  # noqa: E501

        :return: The notify_type of this WebhookJob.  # noqa: E501
        :rtype: str
        """
        return self._notify_type

    @notify_type.setter
    def notify_type(self, notify_type):
        """Sets the notify_type of this WebhookJob.

        The webhook job notify type.  # noqa: E501

        :param notify_type: The notify_type of this WebhookJob.  # noqa: E501
        :type: str
        """

        self._notify_type = notify_type

    @property
    def status(self):
        """Gets the status of this WebhookJob.  # noqa: E501

        The webhook job status.  # noqa: E501

        :return: The status of this WebhookJob.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WebhookJob.

        The webhook job status.  # noqa: E501

        :param status: The status of this WebhookJob.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def job_detail(self):
        """Gets the job_detail of this WebhookJob.  # noqa: E501

        The webhook job notify detailed data.  # noqa: E501

        :return: The job_detail of this WebhookJob.  # noqa: E501
        :rtype: str
        """
        return self._job_detail

    @job_detail.setter
    def job_detail(self, job_detail):
        """Sets the job_detail of this WebhookJob.

        The webhook job notify detailed data.  # noqa: E501

        :param job_detail: The job_detail of this WebhookJob.  # noqa: E501
        :type: str
        """

        self._job_detail = job_detail

    @property
    def creation_time(self):
        """Gets the creation_time of this WebhookJob.  # noqa: E501

        The webhook job creation time.  # noqa: E501

        :return: The creation_time of this WebhookJob.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this WebhookJob.

        The webhook job creation time.  # noqa: E501

        :param creation_time: The creation_time of this WebhookJob.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def update_time(self):
        """Gets the update_time of this WebhookJob.  # noqa: E501

        The webhook job update time.  # noqa: E501

        :return: The update_time of this WebhookJob.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this WebhookJob.

        The webhook job update time.  # noqa: E501

        :param update_time: The update_time of this WebhookJob.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookJob, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ProjectMemberEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'project_id': 'int',
        'entity_name': 'str',
        'role_name': 'str',
        'role_id': 'int',
        'entity_id': 'int',
        'entity_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'project_id': 'project_id',
        'entity_name': 'entity_name',
        'role_name': 'role_name',
        'role_id': 'role_id',
        'entity_id': 'entity_id',
        'entity_type': 'entity_type'
    }

    def __init__(self, id=None, project_id=None, entity_name=None, role_name=None, role_id=None, entity_id=None, entity_type=None, _configuration=None):  # noqa: E501
        """ProjectMemberEntity - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._project_id = None
        self._entity_name = None
        self._role_name = None
        self._role_id = None
        self._entity_id = None
        self._entity_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if project_id is not None:
            self.project_id = project_id
        if entity_name is not None:
            self.entity_name = entity_name
        if role_name is not None:
            self.role_name = role_name
        if role_id is not None:
            self.role_id = role_id
        if entity_id is not None:
            self.entity_id = entity_id
        if entity_type is not None:
            self.entity_type = entity_type

    @property
    def id(self):
        """Gets the id of this ProjectMemberEntity.  # noqa: E501

        the project member id  # noqa: E501

        :return: The id of this ProjectMemberEntity.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProjectMemberEntity.

        the project member id  # noqa: E501

        :param id: The id of this ProjectMemberEntity.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def project_id(self):
        """Gets the project_id of this ProjectMemberEntity.  # noqa: E501

        the project id  # noqa: E501

        :return: The project_id of this ProjectMemberEntity.  # noqa: E501
        :rtype: int
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ProjectMemberEntity.

        the project id  # noqa: E501

        :param project_id: The project_id of this ProjectMemberEntity.  # noqa: E501
        :type: int
        """

        self._project_id = project_id

    @property
    def entity_name(self):
        """Gets the entity_name of this ProjectMemberEntity.  # noqa: E501

        the name of the group member.  # noqa: E501

        :return: The entity_name of this ProjectMemberEntity.  # noqa: E501
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """Sets the entity_name of this ProjectMemberEntity.

        the name of the group member.  # noqa: E501

        :param entity_name: The entity_name of this ProjectMemberEntity.  # noqa: E501
        :type: str
        """

        self._entity_name = entity_name

    @property
    def role_name(self):
        """Gets the role_name of this ProjectMemberEntity.  # noqa: E501

        the name of the role  # noqa: E501

        :return: The role_name of this ProjectMemberEntity.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this ProjectMemberEntity.

        the name of the role  # noqa: E501

        :param role_name: The role_name of this ProjectMemberEntity.  # noqa: E501
        :type: str
        """

        self._role_name = role_name

    @property
    def role_id(self):
        """Gets the role_id of this ProjectMemberEntity.  # noqa: E501

        the role id  # noqa: E501

        :return: The role_id of this ProjectMemberEntity.  # noqa: E501
        :rtype: int
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this ProjectMemberEntity.

        the role id  # noqa: E501

        :param role_id: The role_id of this ProjectMemberEntity.  # noqa: E501
        :type: int
        """

        self._role_id = role_id

    @property
    def entity_id(self):
        """Gets the entity_id of this ProjectMemberEntity.  # noqa: E501

        the id of entity, if the member is a user, it is user_id in user table. if the member is a user group, it is the user group's ID in user_group table.  # noqa: E501

        :return: The entity_id of this ProjectMemberEntity.  # noqa: E501
        :rtype: int
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this ProjectMemberEntity.

        the id of entity, if the member is a user, it is user_id in user table. if the member is a user group, it is the user group's ID in user_group table.  # noqa: E501

        :param entity_id: The entity_id of this ProjectMemberEntity.  # noqa: E501
        :type: int
        """

        self._entity_id = entity_id

    @property
    def entity_type(self):
        """Gets the entity_type of this ProjectMemberEntity.  # noqa: E501

        the entity's type, u for user entity, g for group entity.  # noqa: E501

        :return: The entity_type of this ProjectMemberEntity.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this ProjectMemberEntity.

        the entity's type, u for user entity, g for group entity.  # noqa: E501

        :param entity_type: The entity_type of this ProjectMemberEntity.  # noqa: E501
        :type: str
        """

        self._entity_type = entity_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectMemberEntity, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectMemberEntity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProjectMemberEntity):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class RetentionExecutionTask(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'execution_id': 'int',
        'repository': 'str',
        'job_id': 'str',
        'status': 'str',
        'status_code': 'int',
        'status_revision': 'int',
        'start_time': 'str',
        'end_time': 'str',
        'total': 'int',
        'retained': 'int'
    }

    attribute_map = {
        'id': 'id',
        'execution_id': 'execution_id',
        'repository': 'repository',
        'job_id': 'job_id',
        'status': 'status',
        'status_code': 'status_code',
        'status_revision': 'status_revision',
        'start_time': 'start_time',
        'end_time': 'end_time',
        'total': 'total',
        'retained': 'retained'
    }

    def __init__(self, id=None, execution_id=None, repository=None, job_id=None, status=None, status_code=None, status_revision=None, start_time=None, end_time=None, total=None, retained=None, _configuration=None):  # noqa: E501
        """RetentionExecutionTask - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._execution_id = None
        self._repository = None
        self._job_id = None
        self._status = None
        self._status_code = None
        self._status_revision = None
        self._start_time = None
        self._end_time = None
        self._total = None
        self._retained = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if execution_id is not None:
            self.execution_id = execution_id
        if repository is not None:
            self.repository = repository
        if job_id is not None:
            self.job_id = job_id
        if status is not None:
            self.status = status
        if status_code is not None:
            self.status_code = status_code
        if status_revision is not None:
            self.status_revision = status_revision
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if total is not None:
            self.total = total
        if retained is not None:
            self.retained = retained

    @property
    def id(self):
        """Gets the id of this RetentionExecutionTask.  # noqa: E501


        :return: The id of this RetentionExecutionTask.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RetentionExecutionTask.


        :param id: The id of this RetentionExecutionTask.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def execution_id(self):
        """Gets the execution_id of this RetentionExecutionTask.  # noqa: E501


        :return: The execution_id of this RetentionExecutionTask.  # noqa: E501
        :rtype: int
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this RetentionExecutionTask.


        :param execution_id: The execution_id of this RetentionExecutionTask.  # noqa: E501
        :type: int
        """

        self._execution_id = execution_id

    @property
    def repository(self):
        """Gets the repository of this RetentionExecutionTask.  # noqa: E501


        :return: The repository of this RetentionExecutionTask.  # noqa: E501
        :rtype: str
        """
        return self._repository

    @repository.setter
    def repository(self, repository):
        """Sets the repository of this RetentionExecutionTask.


        :param repository: The repository of this RetentionExecutionTask.  # noqa: E501
        :type: str
        """

        self._repository = repository

    @property
    def job_id(self):
        """Gets the job_id of this RetentionExecutionTask.  # noqa: E501


        :return: The job_id of this RetentionExecutionTask.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this RetentionExecutionTask.


        :param job_id: The job_id of this RetentionExecutionTask.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def status(self):
        """Gets the status of this RetentionExecutionTask.  # noqa: E501


        :return: The status of this RetentionExecutionTask.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RetentionExecutionTask.


        :param status: The status of this RetentionExecutionTask.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def status_code(self):
        """Gets the status_code of this RetentionExecutionTask.  # noqa: E501


        :return: The status_code of this RetentionExecutionTask.  # noqa: E501
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this RetentionExecutionTask.


        :param status_code: The status_code of this RetentionExecutionTask.  # noqa: E501
        :type: int
        """

        self._status_code = status_code

    @property
    def status_revision(self):
        """Gets the status_revision of this RetentionExecutionTask.  # noqa: E501


        :return: The status_revision of this RetentionExecutionTask.  # noqa: E501
        :rtype: int
        """
        return self._status_revision

    @status_revision.setter
    def status_revision(self, status_revision):
        """Sets the status_revision of this RetentionExecutionTask.


        :param status_revision: The status_revision of this RetentionExecutionTask.  # noqa: E501
        :type: int
        """

        self._status_revision = status_revision

    @property
    def start_time(self):
        """Gets the start_time of this RetentionExecutionTask.  # noqa: E501


        :return: The start_time of this RetentionExecutionTask.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this RetentionExecutionTask.


        :param start_time: The start_time of this RetentionExecutionTask.  # noqa: E501
        :type: str
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this RetentionExecutionTask.  # noqa: E501


        :return: The end_time of this RetentionExecutionTask.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this RetentionExecutionTask.


        :param end_time: The end_time of this RetentionExecutionTask.  # noqa: E501
        :type: str
        """

        self._end_time = end_time

    @property
    def total(self):
        """Gets the total of this RetentionExecutionTask.  # noqa: E501


        :return: The total of this RetentionExecutionTask.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this RetentionExecutionTask.


        :param total: The total of this RetentionExecutionTask.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def retained(self):
        """Gets the retained of this RetentionExecutionTask.  # noqa: E501


        :return: The retained of this RetentionExecutionTask.  # noqa: E501
        :rtype: int
        """
        return self._retained

    @retained.setter
    def retained(self, retained):
        """Sets the retained of this RetentionExecutionTask.


        :param retained: The retained of this RetentionExecutionTask.  # noqa: E501
        :type: int
        """

        self._retained = retained

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RetentionExecutionTask, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetentionExecutionTask):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RetentionExecutionTask):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Stats(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'total': 'int',
        'completed': 'int',
        'metrics': 'dict(str, int)',
        'ongoing': 'bool',
        'trigger': 'str'
    }

    attribute_map = {
        'total': 'total',
        'completed': 'completed',
        'metrics': 'metrics',
        'ongoing': 'ongoing',
        'trigger': 'trigger'
    }

    def __init__(self, total=None, completed=None, metrics=None, ongoing=None, trigger=None, _configuration=None):  # noqa: E501
        """Stats - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._total = None
        self._completed = None
        self._metrics = None
        self._ongoing = None
        self._trigger = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if completed is not None:
            self.completed = completed
        if metrics is not None:
            self.metrics = metrics
        if ongoing is not None:
            self.ongoing = ongoing
        if trigger is not None:
            self.trigger = trigger

    @property
    def total(self):
        """Gets the total of this Stats.  # noqa: E501

        The total number of scan processes triggered by the scan all action  # noqa: E501

        :return: The total of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this Stats.

        The total number of scan processes triggered by the scan all action  # noqa: E501

        :param total: The total of this Stats.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def completed(self):
        """Gets the completed of this Stats.  # noqa: E501

        The number of the finished scan processes triggered by the scan all action  # noqa: E501

        :return: The completed of this Stats.  # noqa: E501
        :rtype: int
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """Sets the completed of this Stats.

        The number of the finished scan processes triggered by the scan all action  # noqa: E501

        :param completed: The completed of this Stats.  # noqa: E501
        :type: int
        """

        self._completed = completed

    @property
    def metrics(self):
        """Gets the metrics of this Stats.  # noqa: E501

        The metrics data for the each status  # noqa: E501

        :return: The metrics of this Stats.  # noqa: E501
        :rtype: dict(str, int)
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this Stats.

        The metrics data for the each status  # noqa: E501

        :param metrics: The metrics of this Stats.  # noqa: E501
        :type: dict(str, int)
        """

        self._metrics = metrics

    @property
    def ongoing(self):
        """Gets the ongoing of this Stats.  # noqa: E501

        A flag indicating job status of scan all.  # noqa: E501

        :return: The ongoing of this Stats.  # noqa: E501
        :rtype: bool
        """
        return self._ongoing

    @ongoing.setter
    def ongoing(self, ongoing):
        """Sets the ongoing of this Stats.

        A flag indicating job status of scan all.  # noqa: E501

        :param ongoing: The ongoing of this Stats.  # noqa: E501
        :type: bool
        """

        self._ongoing = ongoing

    @property
    def trigger(self):
        """Gets the trigger of this Stats.  # noqa: E501

        The trigger of the scan all job.  # noqa: E501

        :return: The trigger of this Stats.  # noqa: E501
        :rtype: str
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this Stats.

        The trigger of the scan all job.  # noqa: E501

        :param trigger: The trigger of this Stats.  # noqa: E501
        :type: str
        """
        allowed_values = ["Manual", "Schedule", "Event"]  # noqa: E501
        if (self._configuration.client_side_validation and
                trigger not in allowed_values):
            raise ValueError(
                "Invalid value for `trigger` ({0}), must be one of {1}"  # noqa: E501
                .format(trigger, allowed_values)
            )

        self._trigger = trigger

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Stats, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Stats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Stats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ProviderUnderProject(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'provider': 'str',
        'enabled': 'bool',
        'default': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'provider': 'provider',
        'enabled': 'enabled',
        'default': 'default'
    }

    def __init__(self, id=None, provider=None, enabled=None, default=None, _configuration=None):  # noqa: E501
        """ProviderUnderProject - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._provider = None
        self._enabled = None
        self._default = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if provider is not None:
            self.provider = provider
        if enabled is not None:
            self.enabled = enabled
        if default is not None:
            self.default = default

    @property
    def id(self):
        """Gets the id of this ProviderUnderProject.  # noqa: E501


        :return: The id of this ProviderUnderProject.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProviderUnderProject.


        :param id: The id of this ProviderUnderProject.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def provider(self):
        """Gets the provider of this ProviderUnderProject.  # noqa: E501


        :return: The provider of this ProviderUnderProject.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this ProviderUnderProject.


        :param provider: The provider of this ProviderUnderProject.  # noqa: E501
        :type: str
        """

        self._provider = provider

    @property
    def enabled(self):
        """Gets the enabled of this ProviderUnderProject.  # noqa: E501


        :return: The enabled of this ProviderUnderProject.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ProviderUnderProject.


        :param enabled: The enabled of this ProviderUnderProject.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def default(self):
        """Gets the default of this ProviderUnderProject.  # noqa: E501


        :return: The default of this ProviderUnderProject.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this ProviderUnderProject.


        :param default: The default of this ProviderUnderProject.  # noqa: E501
        :type: bool
        """

        self._default = default

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProviderUnderProject, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProviderUnderProject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProviderUnderProject):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from harbor_client.api_client import ApiClient


class ScanApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_report_log(self, project_name, repository_name, reference, report_id, **kwargs):  # noqa: E501
        """Get the log of the scan report  # noqa: E501

        Get the log of the scan report  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report_log(project_name, repository_name, reference, report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name: The name of the project (required)
        :param str repository_name: The name of the repository. If it contains slash, encode it with URL encoding. e.g. a/b -> a%252Fb (required)
        :param str reference: The reference of the artifact, can be digest or tag (required)
        :param str report_id: The report id to get the log (required)
        :param str x_request_id: An unique ID for the request
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_report_log_with_http_info(project_name, repository_name, reference, report_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_report_log_with_http_info(project_name, repository_name, reference, report_id, **kwargs)  # noqa: E501
            return data

    def get_report_log_with_http_info(self, project_name, repository_name, reference, report_id, **kwargs):  # noqa: E501
        """Get the log of the scan report  # noqa: E501

        Get the log of the scan report  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report_log_with_http_info(project_name, repository_name, reference, report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name: The name of the project (required)
        :param str repository_name: The name of the repository. If it contains slash, encode it with URL encoding. e.g. a/b -> a%252Fb (required)
        :param str reference: The reference of the artifact, can be digest or tag (required)
        :param str report_id: The report id to get the log (required)
        :param str x_request_id: An unique ID for the request
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_name', 'repository_name', 'reference', 'report_id', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_report_log" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_name' is set
        if self.api_client.client_side_validation and ('project_name' not in params or
                                                       params['project_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_name` when calling `get_report_log`")  # noqa: E501
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in params or
                                                       params['repository_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `repository_name` when calling `get_report_log`")  # noqa: E501
        # verify the required parameter 'reference' is set
        if self.api_client.client_side_validation and ('reference' not in params or
                                                       params['reference'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `reference` when calling `get_report_log`")  # noqa: E501
        # verify the required parameter 'report_id' is set
        if self.api_client.client_side_validation and ('report_id' not in params or
                                                       params['report_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `report_id` when calling `get_report_log`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_report_log`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'project_name' in params:
            path_params['project_name'] = params['project_name']  # noqa: E501
        if 'repository_name' in params:
            path_params['repository_name'] = params['repository_name']  # noqa: E501
        if 'reference' in params:
            path_params['reference'] = params['reference']  # noqa: E501
        if 'report_id' in params:
            path_params['report_id'] = params['report_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_name}/repositories/{repository_name}/artifacts/{reference}/scan/{report_id}/log', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def scan_artifact(self, project_name, repository_name, reference, **kwargs):  # noqa: E501
        """Scan the artifact  # noqa: E501

        Scan the specified artifact  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_artifact(project_name, repository_name, reference, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name: The name of the project (required)
        :param str repository_name: The name of the repository. If it contains slash, encode it with URL encoding. e.g. a/b -> a%252Fb (required)
        :param str reference: The reference of the artifact, can be digest or tag (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.scan_artifact_with_http_info(project_name, repository_name, reference, **kwargs)  # noqa: E501
        else:
            (data) = self.scan_artifact_with_http_info(project_name, repository_name, reference, **kwargs)  # noqa: E501
            return data

    def scan_artifact_with_http_info(self, project_name, repository_name, reference, **kwargs):  # noqa: E501
        """Scan the artifact  # noqa: E501

        Scan the specified artifact  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.scan_artifact_with_http_info(project_name, repository_name, reference, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name: The name of the project (required)
        :param str repository_name: The name of the repository. If it contains slash, encode it with URL encoding. e.g. a/b -> a%252Fb (required)
        :param str reference: The reference of the artifact, can be digest or tag (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_name', 'repository_name', 'reference', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method scan_artifact" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_name' is set
        if self.api_client.client_side_validation and ('project_name' not in params or
                                                       params['project_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_name` when calling `scan_artifact`")  # noqa: E501
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in params or
                                                       params['repository_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `repository_name` when calling `scan_artifact`")  # noqa: E501
        # verify the required parameter 'reference' is set
        if self.api_client.client_side_validation and ('reference' not in params or
                                                       params['reference'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `reference` when calling `scan_artifact`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `scan_artifact`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'project_name' in params:
            path_params['project_name'] = params['project_name']  # noqa: E501
        if 'repository_name' in params:
            path_params['repository_name'] = params['repository_name']  # noqa: E501
        if 'reference' in params:
            path_params['reference'] = params['reference']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_name}/repositories/{repository_name}/artifacts/{reference}/scan', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def stop_scan_artifact(self, project_name, repository_name, reference, **kwargs):  # noqa: E501
        """Cancelling a scan job for a particular artifact  # noqa: E501

        Cancelling a scan job for a particular artifact  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_scan_artifact(project_name, repository_name, reference, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name: The name of the project (required)
        :param str repository_name: The name of the repository. If it contains slash, encode it with URL encoding. e.g. a/b -> a%252Fb (required)
        :param str reference: The reference of the artifact, can be digest or tag (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.stop_scan_artifact_with_http_info(project_name, repository_name, reference, **kwargs)  # noqa: E501
        else:
            (data) = self.stop_scan_artifact_with_http_info(project_name, repository_name, reference, **kwargs)  # noqa: E501
            return data

    def stop_scan_artifact_with_http_info(self, project_name, repository_name, reference, **kwargs):  # noqa: E501
        """Cancelling a scan job for a particular artifact  # noqa: E501

        Cancelling a scan job for a particular artifact  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_scan_artifact_with_http_info(project_name, repository_name, reference, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name: The name of the project (required)
        :param str repository_name: The name of the repository. If it contains slash, encode it with URL encoding. e.g. a/b -> a%252Fb (required)
        :param str reference: The reference of the artifact, can be digest or tag (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_name', 'repository_name', 'reference', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method stop_scan_artifact" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_name' is set
        if self.api_client.client_side_validation and ('project_name' not in params or
                                                       params['project_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_name` when calling `stop_scan_artifact`")  # noqa: E501
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in params or
                                                       params['repository_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `repository_name` when calling `stop_scan_artifact`")  # noqa: E501
        # verify the required parameter 'reference' is set
        if self.api_client.client_side_validation and ('reference' not in params or
                                                       params['reference'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `reference` when calling `stop_scan_artifact`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `stop_scan_artifact`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'project_name' in params:
            path_params['project_name'] = params['project_name']  # noqa: E501
        if 'repository_name' in params:
            path_params['repository_name'] = params['repository_name']  # noqa: E501
        if 'reference' in params:
            path_params['reference'] = params['reference']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_name}/repositories/{repository_name}/artifacts/{reference}/scan/stop', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
